@@ -136,6 +136,9 @@ class Pie(object):
         os.mkdir(REPOSITORY_PATH)
         os.mkdir(PIECES_DIR)
 
+        # the key is used to encode and decode
+        # UToken tokens.
+
         key = hashlib.sha256(secrets.token_bytes(32)).hexdigest()
 
         repository_info = {
@@ -214,8 +217,8 @@ class Pie(object):
 
         file_lines = {}
 
-        # removing "\n" only from the end of the line
         for line, text in enumerate(file):
+            # removing "\n" only from the end of the line
             if text[-1::] == '\n':
                 text = text[:-1]
 
@@ -547,17 +550,13 @@ class Pie(object):
         tracked_files = self.get_tracked_files()
         merged_files = []
 
-        # def callback(fn: futures.Future):
-        #     result = fn.result()
-        #     if result:
-        #         merged_files.append(result)
-
         with futures.ThreadPoolExecutor() as executor:
             threads = []
 
             for filepath in tracked_files.keys():
                 future = executor.submit(self._merge_file, filepath)
-                future.add_done_callback(lambda fn: merged_files.append(fn.result()) if fn.result() else None)
+                callback = lambda fn: merged_files.append(fn.result()) if fn.result() else None
+                future.add_done_callback(callback)
                 threads.append(future)
 
             while not all([i.done() for i in threads]):
